==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24RecentSwatchPanel.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$RecentSwatchPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class a04d8ae1b1980f4 javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel
// @dep_class 3146b457beeae28 javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

#include "javax/swing/colorchooser/DefaultSwatchChooserPanel__24SwatchPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct {
	struct _jc_java_awt_Color$object	*defaultColor;
};
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$addColorToQueue$76fab914c15d56dd(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Color$object *);
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$getColorForPosition$9e238dcc81583aa7(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint);
extern jint _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$getIndexForCell$eb08bc333358215b(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$getToolTipText$69909437751767f6(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$initializeColors$177c4c7d81450fda(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$addColorToQueue$76fab914c15d56dd;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$getColorForPosition$9e238dcc81583aa7;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$getIndexForCell$eb08bc333358215b;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$getToolTipText$69909437751767f6;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$initializeColors$177c4c7d81450fda;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$access__240$e945f0730b1ae255(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Color$object *);

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods {
	void	(*addColorToQueue$76fab914c15d56dd)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Color$object *);
	struct _jc_java_awt_Color$object	*(*getColorForPosition$9e238dcc81583aa7)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint);
	jint	(*getIndexForCell$eb08bc333358215b)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint);
	struct _jc_java_lang_String$object	*(*getToolTipText$69909437751767f6)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*initializeColors$177c4c7d81450fda)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Graphics$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs {
	_jc_object_array	*colors;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs {
	jint	start;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24RecentSwatchPanel.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$RecentSwatchPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 7f52e60a182f9900 javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel
// @dep_class 3146b457beeae28 javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

#include "javax/swing/colorchooser/DefaultSwatchChooserPanel__24SwatchPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct {
	struct _jc_java_awt_Color$object	*defaultColor;
};
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$fields_struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$addColorToQueue$76fab914c15d56dd(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$getColorForPosition$9e238dcc81583aa7(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$getIndexForCell$eb08bc333358215b(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$getToolTipText$69909437751767f6(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$initializeColors$177c4c7d81450fda(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$addColorToQueue$76fab914c15d56dd;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$getColorForPosition$9e238dcc81583aa7;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$getIndexForCell$eb08bc333358215b;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$getToolTipText$69909437751767f6;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$initializeColors$177c4c7d81450fda;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods {
	void	(*addColorToQueue$76fab914c15d56dd)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Color$object	*(*getColorForPosition$9e238dcc81583aa7)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
	jint	(*getIndexForCell$eb08bc333358215b)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getToolTipText$69909437751767f6)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*initializeColors$177c4c7d81450fda)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs {
	_jc_object_array	*colors;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs {
	jint	start;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel_H_ */
